@@ -70,8 +70,7 @@ get_dfm <- function(tc, feature, context_level=c('document','sentence'), weight=
 do_get_dtm <- function(tc, feature, context_level=c('document','sentence'), weight=c('termfreq','docfreq','tfidf','norm_tfidf'), drop_empty_terms=T, form=c('Matrix', 'tm_dtm', 'quanteda_dfm'), subset_tokens=NULL, subset_meta=NULL, context=NULL, context_labels=T, feature_labels=T, ngrams=NA, ngram_before_subset=F){
   form = match.arg(form)
   if(form == 'tm_dtm') require_package('tm', '0.6')
-  if(form == 'quanteda_dfm') require_package('quanteda', '1.1.1')
-  is_tcorpus(tc, T)
+  is_tcorpus(tc)
   weight = match.arg(weight)
   context_levels = match.arg(context_level)
 
