@@ -161,7 +161,7 @@ tCorpus$set('public', 'subset_query', function(query, feature='token', context_l
 #'
 #' }
 search_contexts <- function(tc, query, code=NULL, feature='token', context_level=c('document','sentence'), verbose=F, as_ascii=F){
-  is_tcorpus(tc, T)
+  is_tcorpus(tc)
   context_level = match.arg(context_level)
   if (!feature %in% tc$names) stop(sprintf('Feature (%s) is not available. Current options are: %s', feature, paste(tc$feature_names, collapse=', ')))
   codelabel = get_query_code(query, code)
